<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage STEPHANIE_KING
 * @since STEPHANIE_KING 1.0
 */

stephanie_king_storage_set('blog_archive', true);

// Load scripts for both 'Gallery' and 'Portfolio' layouts!
wp_enqueue_script( 'imagesloaded' );
wp_enqueue_script( 'masonry' );
wp_enqueue_script( 'classie', stephanie_king_get_file_url('js/theme.gallery/classie.min.js'), array(), null, true );
wp_enqueue_script( 'stephanie-king-gallery-script', stephanie_king_get_file_url('js/theme.gallery/theme.gallery.js'), array(), null, true );

get_header(); 

if (have_posts()) {

	echo get_query_var('blog_archive_start');

	$stephanie_king_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$stephanie_king_sticky_out = stephanie_king_get_theme_option('sticky_style')=='columns' 
							&& is_array($stephanie_king_stickies) && count($stephanie_king_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$stephanie_king_cat = stephanie_king_get_theme_option('parent_cat');
	$stephanie_king_post_type = stephanie_king_get_theme_option('post_type');
	$stephanie_king_taxonomy = stephanie_king_get_post_type_taxonomy($stephanie_king_post_type);
	$stephanie_king_show_filters = stephanie_king_get_theme_option('show_filters');
	$stephanie_king_tabs = array();
	if (!stephanie_king_is_off($stephanie_king_show_filters)) {
		$stephanie_king_args = array(
			'type'			=> $stephanie_king_post_type,
			'child_of'		=> $stephanie_king_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $stephanie_king_taxonomy,
			'pad_counts'	=> false
		);
		$stephanie_king_portfolio_list = get_terms($stephanie_king_args);
		if (is_array($stephanie_king_portfolio_list) && count($stephanie_king_portfolio_list) > 0) {
			$stephanie_king_tabs[$stephanie_king_cat] = esc_html__('All', 'stephanie-king');
			foreach ($stephanie_king_portfolio_list as $stephanie_king_term) {
				if (isset($stephanie_king_term->term_id)) $stephanie_king_tabs[$stephanie_king_term->term_id] = $stephanie_king_term->name;
			}
		}
	}
	if (count($stephanie_king_tabs) > 0) {
		$stephanie_king_portfolio_filters_ajax = true;
		$stephanie_king_portfolio_filters_active = $stephanie_king_cat;
		$stephanie_king_portfolio_filters_id = 'portfolio_filters';
		if (!is_customize_preview())
			wp_enqueue_script('jquery-ui-tabs', false, array('jquery', 'jquery-ui-core'), null, true);
		?>
		<div class="portfolio_filters stephanie_king_tabs stephanie_king_tabs_ajax">
			<ul class="portfolio_titles stephanie_king_tabs_titles">
				<?php
				foreach ($stephanie_king_tabs as $stephanie_king_id=>$stephanie_king_title) {
					?><li><a href="<?php echo esc_url(stephanie_king_get_hash_link(sprintf('#%s_%s_content', $stephanie_king_portfolio_filters_id, $stephanie_king_id))); ?>" data-tab="<?php echo esc_attr($stephanie_king_id); ?>"><?php echo esc_html($stephanie_king_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$stephanie_king_ppp = stephanie_king_get_theme_option('posts_per_page');
			if (stephanie_king_is_inherit($stephanie_king_ppp)) $stephanie_king_ppp = '';
			foreach ($stephanie_king_tabs as $stephanie_king_id=>$stephanie_king_title) {
				$stephanie_king_portfolio_need_content = $stephanie_king_id==$stephanie_king_portfolio_filters_active || !$stephanie_king_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $stephanie_king_portfolio_filters_id, $stephanie_king_id)); ?>"
					class="portfolio_content stephanie_king_tabs_content"
					data-blog-template="<?php echo esc_attr(stephanie_king_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(stephanie_king_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($stephanie_king_ppp); ?>"
					data-post-type="<?php echo esc_attr($stephanie_king_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($stephanie_king_taxonomy); ?>"
					data-cat="<?php echo esc_attr($stephanie_king_id); ?>"
					data-parent-cat="<?php echo esc_attr($stephanie_king_cat); ?>"
					data-need-content="<?php echo (false===$stephanie_king_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($stephanie_king_portfolio_need_content) 
						stephanie_king_show_portfolio_posts(array(
							'cat' => $stephanie_king_id,
							'parent_cat' => $stephanie_king_cat,
							'taxonomy' => $stephanie_king_taxonomy,
							'post_type' => $stephanie_king_post_type,
							'page' => 1,
							'sticky' => $stephanie_king_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		stephanie_king_show_portfolio_posts(array(
			'cat' => $stephanie_king_cat,
			'parent_cat' => $stephanie_king_cat,
			'taxonomy' => $stephanie_king_taxonomy,
			'post_type' => $stephanie_king_post_type,
			'page' => 1,
			'sticky' => $stephanie_king_sticky_out
			)
		);
	}

	echo get_query_var('blog_archive_end');

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>