<?php
/**
 * Default Theme Options and Internal Theme Settings
 *
 * @package WordPress
 * @subpackage STEPHANIE_KING
 * @since STEPHANIE_KING 1.0
 */

// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)


if ( !function_exists('stephanie_king_options_theme_setup1') ) {
	add_action( 'after_setup_theme', 'stephanie_king_options_theme_setup1', 1 );
	function stephanie_king_options_theme_setup1() {
		
		// -----------------------------------------------------------------
		// -- ONLY FOR PROGRAMMERS, NOT FOR CUSTOMER
		// -- Internal theme settings
		// -----------------------------------------------------------------
		stephanie_king_storage_set('settings', array(
			
			'disable_jquery_ui'		=> false,		// Prevent loading custom jQuery UI libraries in the third-party plugins
		
			'max_load_fonts'		=> 3,			// Max fonts number to load from Google fonts or from uploaded fonts
		
			'use_mediaelements'		=> true,		// Load script "Media Elements" to play video and audio
		
			'max_excerpt_length'	=> 45,			// Max words number for the excerpt in the blog style 'Excerpt'.
													// For style 'Classic' - get half from this value

			'comment_maxlength'		=> 1000,		// Max length of the message from contact form

			'comment_after_name'	=> true,		// Place 'comment' field before the 'name' and 'email'
			
			'socials_type'			=> 'icons',		// Type of socials:
													// icons - use fontello icons to present social networks
													// images - use images from theme's folder trx_addons/css/icons.png
			
			'icons_type'			=> 'icons',		// Type of other icons:
													// icons - use fontello icons to present icons
													// images - use images from theme's folder trx_addons/css/icons.png
			
			'icons_selector'		=> 'internal'	// Icons selector in the shortcodes:
													// vc (default) - standard VC icons selector (very slow and don't support images)
													// internal - internal popup with plugin's or theme's icons list (fast)
		));
	}
}


// -----------------------------------------------------------------
// -- Theme options for customizer
// -----------------------------------------------------------------
if (!function_exists('stephanie_king_options_create')) {

	function stephanie_king_options_create() {

		// Message about options override. 
		// Attention! Not need esc_html() here, because this message put in wp_kses_data() below
		$msg_override = __('<b>Attention!</b> Some of these options can be overridden in the following sections (Homepage, Blog archive, Shop, Events, etc.) or in the settings of individual pages', 'stephanie-king');

		stephanie_king_storage_set('options', array(
		
			// Section 'Title & Tagline' - add theme options in the standard WP section
			'title_tagline' => array(
				"title" => esc_html__('Title, Tagline & Site icon', 'stephanie-king'),
				"desc" => wp_kses_data( __('Specify site title and tagline (if need) and upload the site icon', 'stephanie-king') ),
				"type" => "section"
				),
		
		
			// Section 'Header' - add theme options in the standard WP section
			'header_image' => array(
				"title" => esc_html__('Header', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload logo images, select header type and widgets set for the header', 'stephanie-king') )
							. '<br>'
							. wp_kses_data( $msg_override ),
				"type" => "section"
				),
			'header_image_override' => array(
				"title" => esc_html__('Header image override', 'stephanie-king'),
				"desc" => wp_kses_data( __("Allow override the header image with the page's/post's/product's/etc. featured image", 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'stephanie-king')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_style' => array(
				"title" => esc_html__('Header style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select style to display the site header', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'stephanie-king')
				),
				"std" => 'header-default',
				"options" => array(),
				"type" => "select"
				),
			'header_position' => array(
				"title" => esc_html__('Header position', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select position to display the site header', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'stephanie-king')
				),
				"std" => 'default',
				"options" => array(),
				"type" => "select"
				),
			'header_scheme' => array(
				"title" => esc_html__('Header Color Scheme', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select color scheme to decorate header area', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'stephanie-king')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => "select"
				),

			'menu_info' => array(
				"title" => esc_html__('Menu settings', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select main menu style, position, color scheme and other parameters', 'stephanie-king') ),
				"type" => "info"
				),
			'menu_style' => array(
				"title" => esc_html__('Menu position', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select position of the main menu', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'stephanie-king')
				),
				"std" => 'top',
				"options" => array(
					'top'	=> esc_html__('Top',	'stephanie-king')
				),
				"type" => "switch"
				),
			'menu_scheme' => array(
				"title" => esc_html__('Menu Color Scheme', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select color scheme to decorate main menu area', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'stephanie-king')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => "select"
				),
			'menu_side_stretch' => array(
				"title" => esc_html__('Stretch sidemenu', 'stephanie-king'),
				"desc" => wp_kses_data( __('Stretch sidemenu to window height (if menu items number >= 5)', 'stephanie-king') ),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'menu_side_icons' => array(
				"title" => esc_html__('Iconed sidemenu', 'stephanie-king'),
				"desc" => wp_kses_data( __('Get icons from anchors and display it in the sidemenu or mark sidemenu items with simple dots', 'stephanie-king') ),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'menu_mobile_fullscreen' => array(
				"title" => esc_html__('Mobile menu fullscreen', 'stephanie-king'),
				"desc" => wp_kses_data( __('Display mobile and side menus on full screen (if checked) or slide narrow menu from the left or from the right side (if not checked)', 'stephanie-king') ),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'logo_info' => array(
				"title" => esc_html__('Logo settings', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select logo images for the normal and Retina displays', 'stephanie-king') ),
				"type" => "info"
				),
			'logo' => array(
				"title" => esc_html__('Logo', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload site logo', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			'logo_retina' => array(
				"title" => esc_html__('Logo for Retina', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			'logo_inverse' => array(
				"title" => esc_html__('Logo inverse', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it on the dark background', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			'logo_inverse_retina' => array(
				"title" => esc_html__('Logo inverse for Retina', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			'logo_side' => array(
				"title" => esc_html__('Logo side', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			'logo_side_retina' => array(
				"title" => esc_html__('Logo side for Retina', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu on Retina displays (if empty - use default logo from the field above)', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			'logo_text' => array(
				"title" => esc_html__('Logo from Site name', 'stephanie-king'),
				"desc" => wp_kses_data( __('Do you want use Site name and description as Logo if images above are not selected?', 'stephanie-king') ),
				"std" => 1,
				"type" => "checkbox"
				),
			'title_image' => array(
				"title" => esc_html__('Image for title', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload image for title (Only for default header)', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			
		
		
			// Section 'Content'
			'content' => array(
				"title" => esc_html__('Content', 'stephanie-king'),
				"desc" => wp_kses_data( __('Options of the content area.', 'stephanie-king') )
							. '<br>'
							. wp_kses_data( $msg_override ),
				"type" => "section",
				),
			'color_scheme' => array(
				"title" => esc_html__('Site Color Scheme', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select color scheme to decorate whole site. Attention! Case "Inherit" can be used only for custom pages, not for root site content in the Appearance - Customize', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"std" => 'default',
				"options" => array(),
				"refresh" => false,
				"type" => "select"
				),
			'body_style' => array(
				"title" => esc_html__('Body style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select width of the body content', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"refresh" => false,
				"std" => 'wide',
				"options" => array(
					'boxed'		=> esc_html__('Boxed',		'stephanie-king'),
					'wide'		=> esc_html__('Wide',		'stephanie-king'),
					'fullwide'	=> esc_html__('Fullwide',	'stephanie-king'),
					'fullscreen'=> esc_html__('Fullscreen',	'stephanie-king')
				),
				"type" => "select"
				),
			'boxed_bg_image' => array(
				"title" => esc_html__('Boxed bg image', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload image, used as background in the boxed body', 'stephanie-king') ),
				"dependency" => array(
					'body_style' => array('boxed')
				),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"std" => '',
				"type" => "image"
				),
			'expand_content' => array(
				"title" => esc_html__('Expand content', 'stephanie-king'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'remove_margins' => array(
				"title" => esc_html__('Remove margins', 'stephanie-king'),
				"desc" => wp_kses_data( __('Remove margins above and below the content area', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"refresh" => false,
				"std" => 0,
				"type" => "checkbox"
				),
			'no_image' => array(
				"title" => esc_html__('No image placeholder', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select or upload image, used as placeholder for the posts without featured image', 'stephanie-king') ),
				"std" => '',
				"type" => "image"
				),
			'seo_snippets' => array(
				"title" => esc_html__('SEO snippets', 'stephanie-king'),
				"desc" => wp_kses_data( __('Add structured data markup to the single posts and pages', 'stephanie-king') ),
				"std" => 0,
				"type" => "checkbox"
				),
			'privacy_text' => array(
				"title" => esc_html__("Text with Privacy Policy link", 'stephanie-king'),
				"desc"  => wp_kses_data( __("Specify text with Privacy Policy link for the checkbox 'I agree ...'", 'stephanie-king') ),
				"std"   => wp_kses_post( __( 'I agree that my submitted data is being collected and stored.', 'stephanie-king') ),
				"type"  => "text"
			),
			'author_info' => array(
				"title" => esc_html__('Author info', 'stephanie-king'),
				"desc" => wp_kses_data( __("Display block with information about post's author", 'stephanie-king') ),
				"std" => 1,
				"type" => "checkbox"
				),


			// Section 'Content'
			'sidebar' => array(
				"title" => esc_html__('Sidebar', 'stephanie-king'),
				"desc" => wp_kses_data( __('Options of the sidebar area.', 'stephanie-king') )
							. '<br>'
							. wp_kses_data( $msg_override ),
				"type" => "section",
				),
			'sidebar_widgets' => array(
				"title" => esc_html__('Sidebar widgets', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select default widgets to show in the sidebar', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'stephanie-king')
				),
				"std" => 'sidebar_widgets',
				"options" => array(),
				"type" => "select"
				),
			'sidebar_scheme' => array(
				"title" => esc_html__('Sidebar Color Scheme', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select color scheme to decorate sidebar', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'stephanie-king')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => "select"
				),
			'sidebar_position' => array(
				"title" => esc_html__('Sidebar position', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select position to show sidebar', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'stephanie-king')
				),
				"refresh" => false,
				"std" => 'right',
				"options" => array(),
				"type" => "select"
				),
			'hide_sidebar_on_single' => array(
				"title" => esc_html__('Hide sidebar on the single post', 'stephanie-king'),
				"desc" => wp_kses_data( __("Hide sidebar on the single post's pages", 'stephanie-king') ),
				"std" => 0,
				"type" => "checkbox"
				),
		
		
		
			// Section 'Footer'
			'footer' => array(
				"title" => esc_html__('Footer', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select set of widgets and columns number in the site footer', 'stephanie-king') )
							. '<br>'
							. wp_kses_data( $msg_override ),
				"type" => "section"
				),
			'footer_style' => array(
				"title" => esc_html__('Footer style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select style to display the site footer', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Footer', 'stephanie-king')
				),
				"std" => 'footer-default',
				"options" => array(),
				"type" => "select"
				),
			'footer_scheme' => array(
				"title" => esc_html__('Footer Color Scheme', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select color scheme to decorate footer area', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'stephanie-king')
				),
				"std" => 'dark',
				"options" => array(),
				"refresh" => false,
				"type" => "select"
				),
			'copyright' => array(
				"title" => esc_html__('Copyright', 'stephanie-king'),
				"desc" => wp_kses_data( __('Copyright text in the footer. Use {Y} to insert current year and press "Enter" to create a new line', 'stephanie-king') ),
				"std" => esc_html__('ThemeREX &copy; {Y}. All rights reserved. Terms of use and Privacy Policy', 'stephanie-king'),
				"dependency" => array(
					'footer_style' => array('footer-default')
				),
				"refresh" => false,
				"type" => "textarea"
				),
		
		
		
			// Section 'Homepage' - settings for home page
			'homepage' => array(
				"title" => esc_html__('Homepage', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select blog style and widgets to display on the homepage', 'stephanie-king') ),
				"type" => "section"
				),
			'expand_content_home' => array(
				"title" => esc_html__('Expand content', 'stephanie-king'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden on the Homepage', 'stephanie-king') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'blog_style_home' => array(
				"title" => esc_html__('Blog style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select posts style for the homepage', 'stephanie-king') ),
				"std" => 'excerpt',
				"options" => array(),
				"type" => "select"
				),
			'first_post_large_home' => array(
				"title" => esc_html__('First post large', 'stephanie-king'),
				"desc" => wp_kses_data( __('Make first post large (with Excerpt layout) on the Classic layout of the Homepage', 'stephanie-king') ),
				"dependency" => array(
					'blog_style_home' => array('classic')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_style_home' => array(
				"title" => esc_html__('Header style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select style to display the site header on the homepage', 'stephanie-king') ),
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			'header_position_home' => array(
				"title" => esc_html__('Header position', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select position to display the site header on the homepage', 'stephanie-king') ),
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			'sidebar_widgets_home' => array(
				"title" => esc_html__('Sidebar widgets', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select sidebar to show on the homepage', 'stephanie-king') ),
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			'sidebar_position_home' => array(
				"title" => esc_html__('Sidebar position', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select position to show sidebar on the homepage', 'stephanie-king') ),
				"refresh" => false,
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			
		
		
			// Section 'Blog archive'
			'blog' => array(
				"title" => esc_html__('Blog archive', 'stephanie-king'),
				"desc" => wp_kses_data( __('Options for the blog archive', 'stephanie-king') ),
				"type" => "section",
				),
			'expand_content_blog' => array(
				"title" => esc_html__('Expand content', 'stephanie-king'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden on the blog archive', 'stephanie-king') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'blog_style' => array(
				"title" => esc_html__('Blog style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select posts style for the blog archive', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"dependency" => array(
					'#page_template' => array( 'blog.php' ),
					'.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"std" => 'excerpt',
				"options" => array(),
				"type" => "select"
				),
			'blog_columns' => array(
				"title" => esc_html__('Blog columns', 'stephanie-king'),
				"desc" => wp_kses_data( __('How many columns should be used in the blog archive (from 2 to 4)?', 'stephanie-king') ),
				"std" => 2,
				"options" => stephanie_king_get_list_range(2,4),
				"type" => "hidden"
				),
			'post_type' => array(
				"title" => esc_html__('Post type', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select post type to show in the blog archive', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"dependency" => array(
					'#page_template' => array( 'blog.php' ),
					'.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"linked" => 'parent_cat',
				"refresh" => false,
				"hidden" => true,
				"std" => 'post',
				"options" => array(),
				"type" => "select"
				),
			'parent_cat' => array(
				"title" => esc_html__('Category to show', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select category to show in the blog archive', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"dependency" => array(
					'#page_template' => array( 'blog.php' ),
					'.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"refresh" => false,
				"hidden" => true,
				"std" => '0',
				"options" => array(),
				"type" => "select"
				),
			'posts_per_page' => array(
				"title" => esc_html__('Posts per page', 'stephanie-king'),
				"desc" => wp_kses_data( __('How many posts will be displayed on this page', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"dependency" => array(
					'#page_template' => array( 'blog.php' ),
					'.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"hidden" => true,
				"std" => '',
				"type" => "text"
				),
			"blog_pagination" => array( 
				"title" => esc_html__('Pagination style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Show Older/Newest posts or Page numbers below the posts list', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"std" => "pages",
				"options" => array(
					'pages'	=> esc_html__("Page numbers", 'stephanie-king'),
					'links'	=> esc_html__("Older/Newest", 'stephanie-king'),
					'more'	=> esc_html__("Load more", 'stephanie-king'),
					'infinite' => esc_html__("Infinite scroll", 'stephanie-king')
				),
				"type" => "select"
				),
			'show_filters' => array(
				"title" => esc_html__('Show filters', 'stephanie-king'),
				"desc" => wp_kses_data( __('Show categories as tabs to filter posts', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"dependency" => array(
					'#page_template' => array( 'blog.php' ),
					'.editor-page-attributes__template select' => array( 'blog.php' ),
					'blog_style' => array('portfolio', 'gallery')
				),
				"hidden" => true,
				"std" => 0,
				"type" => "checkbox"
				),
			'first_post_large' => array(
				"title" => esc_html__('First post large', 'stephanie-king'),
				"desc" => wp_kses_data( __('Make first post large (with Excerpt layout) on the Classic layout of blog archive', 'stephanie-king') ),
				"dependency" => array(
					'blog_style' => array('classic')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			"blog_content" => array( 
				"title" => esc_html__('Posts content', 'stephanie-king'),
				"desc" => wp_kses_data( __("Show full post's content in the blog or only post's excerpt", 'stephanie-king') ),
				"std" => "excerpt",
				"options" => array(
					'excerpt'	=> esc_html__('Excerpt',	'stephanie-king'),
					'fullpost'	=> esc_html__('Full post',	'stephanie-king')
				),
				"type" => "select"
				),
			'time_diff_before' => array(
				"title" => esc_html__('Time difference', 'stephanie-king'),
				"desc" => wp_kses_data( __("How many days show time difference instead post's date", 'stephanie-king') ),
				"std" => 5,
				"type" => "text"
				),
			'sticky_style' => array(
				"title" => esc_html__('Sticky posts style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select style of the sticky posts output', 'stephanie-king') ),
				"std" => 'inherit',
				"options" => array(
					'inherit' => esc_html__('Decorated posts', 'stephanie-king'),
					'columns' => esc_html__('Mini-cards',	'stephanie-king')
				),
				"type" => "select"
				),
			"blog_animation" => array( 
				"title" => esc_html__('Animation for the posts', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select animation to show posts in the blog. Attention! Do not use any animation on pages with the "wheel to the anchor" behaviour (like a "Chess 2 columns")!', 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'stephanie-king')
				),
				"dependency" => array(
					'#page_template' => array( 'blog.php' ),
					'.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"std" => "none",
				"options" => array(),
				"type" => "select"
				),
			'header_style_blog' => array(
				"title" => esc_html__('Header style', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select style to display the site header on the blog archive', 'stephanie-king') ),
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			'header_position_blog' => array(
				"title" => esc_html__('Header position', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select position to display the site header on the blog archive', 'stephanie-king') ),
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			'sidebar_widgets_blog' => array(
				"title" => esc_html__('Sidebar widgets', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select sidebar to show on the blog archive', 'stephanie-king') ),
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			'sidebar_position_blog' => array(
				"title" => esc_html__('Sidebar position', 'stephanie-king'),
				"desc" => wp_kses_data( __('Select position to show sidebar on the blog archive', 'stephanie-king') ),
				"refresh" => false,
				"std" => 'inherit',
				"options" => array(),
				"type" => "select"
				),
			'hide_sidebar_on_single_blog' => array(
				"title" => esc_html__('Hide sidebar on the single post', 'stephanie-king'),
				"desc" => wp_kses_data( __("Hide sidebar on the single post", 'stephanie-king') ),
				"std" => 0,
				"type" => "checkbox"
				),
		
		
			// Section 'Colors' - choose color scheme and customize separate colors from it
			'scheme' => array(
				"title" => esc_html__('* Color scheme editor', 'stephanie-king'),
				"desc" => esc_html__("Modify colors and preview changes on your site", 'stephanie-king'),
				"priority" => 1000,
				"type" => "section"
				),
		
			'scheme_storage' => array(
				"title" => esc_html__('Color schemes', 'stephanie-king'),
				"desc" => esc_html__('Select color scheme to modify. Attention! Only those sections will be changed which this scheme was assigned to', 'stephanie-king'),
				"std" => '$stephanie_king_get_scheme_storage',
				"refresh" => false,
				"type" => "scheme_editor"
				),


			// Section 'Hidden'
			'media_title' => array(
				"title" => esc_html__('Media title', 'stephanie-king'),
				"desc" => wp_kses_data( __('Used as title for the audio and video item in this post', 'stephanie-king') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Title', 'stephanie-king')
				),
				"hidden" => true,
				"std" => '',
				"type" => "text"
				),
			'media_author' => array(
				"title" => esc_html__('Media author', 'stephanie-king'),
				"desc" => wp_kses_data( __('Used as author name for the audio and video item in this post', 'stephanie-king') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Title', 'stephanie-king')
				),
				"hidden" => true,
				"std" => '',
				"type" => "text"
				),


			// Internal options.
			// Attention! Don't change any options in the section below!
			'reset_options' => array(
				"title" => '',
				"desc" => '',
				"std" => '0',
				"type" => "hidden",
				),

		));


		// Prepare panel 'Fonts'
		$fonts = array(
		
			// Panel 'Fonts' - manage fonts loading and set parameters of the base theme elements
			'fonts' => array(
				"title" => esc_html__('* Fonts settings', 'stephanie-king'),
				"desc" => '',
				"priority" => 1500,
				"type" => "panel"
				),

			// Section 'Load_fonts'
			'load_fonts' => array(
				"title" => esc_html__('Load fonts', 'stephanie-king'),
				"desc" => wp_kses_data( __('Specify fonts to load when theme start. You can use them in the base theme elements: headers, text, menu, links, input fields, etc.', 'stephanie-king') )
						. '<br>'
						. wp_kses_data( __('<b>Attention!</b> Press "Refresh" button to reload preview area after the all fonts are changed', 'stephanie-king') ),
				"type" => "section"
				),
			'load_fonts_subset' => array(
				"title" => esc_html__('Google fonts subsets', 'stephanie-king'),
				"desc" => wp_kses_data( __('Specify comma separated list of the subsets which will be load from Google fonts', 'stephanie-king') )
						. '<br>'
						. wp_kses_data( __('Available subsets are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese', 'stephanie-king') ),
				"refresh" => false,
				"std" => '$stephanie_king_get_load_fonts_subset',
				"type" => "text"
				)
		);

		for ($i=1; $i<=stephanie_king_get_theme_setting('max_load_fonts'); $i++) {
			$fonts["load_fonts-{$i}-info"] = array(
				"title" => esc_html(sprintf(__('Font %s', 'stephanie-king'), $i)),
				"desc" => '',
				"type" => "info",
				);
			$fonts["load_fonts-{$i}-name"] = array(
				"title" => esc_html__('Font name', 'stephanie-king'),
				"desc" => '',
				"refresh" => false,
				"std" => '$stephanie_king_get_load_fonts_option',
				"type" => "text"
				);
			$fonts["load_fonts-{$i}-family"] = array(
				"title" => esc_html__('Font family', 'stephanie-king'),
				"desc" => $i==1 
							? wp_kses_data( __('Select font family to use it if font above is not available', 'stephanie-king') )
							: '',
				"refresh" => false,
				"std" => '$stephanie_king_get_load_fonts_option',
				"options" => array(
					'inherit' => esc_html__("Inherit", 'stephanie-king'),
					'serif' => esc_html__('serif', 'stephanie-king'),
					'sans-serif' => esc_html__('sans-serif', 'stephanie-king'),
					'monospace' => esc_html__('monospace', 'stephanie-king'),
					'cursive' => esc_html__('cursive', 'stephanie-king'),
					'fantasy' => esc_html__('fantasy', 'stephanie-king')
				),
				"type" => "select"
				);
			$fonts["load_fonts-{$i}-styles"] = array(
				"title" => esc_html__('Font styles', 'stephanie-king'),
				"desc" => $i==1 
							? wp_kses_data( __('Font styles used only for the Google fonts. This is a comma separated list of the font weight and styles. For example: 400,400italic,700', 'stephanie-king') )
											. '<br>'
								. wp_kses_data( __('<b>Attention!</b> Each weight and style increase download size! Specify only used weights and styles.', 'stephanie-king') )
							: '',
				"refresh" => false,
				"std" => '$stephanie_king_get_load_fonts_option',
				"type" => "text"
				);
		}
		$fonts['load_fonts_end'] = array(
			"type" => "section_end"
			);

		// Sections with font's attributes for each theme element
		$theme_fonts = stephanie_king_get_theme_fonts();
		foreach ($theme_fonts as $tag=>$v) {
			$fonts["{$tag}_section"] = array(
				"title" => !empty($v['title']) 
								? $v['title'] 
								: esc_html(sprintf(__('%s settings', 'stephanie-king'), $tag)),
				"desc" => !empty($v['description']) 
								? $v['description'] 
								: wp_kses_post( sprintf(__('Font settings of the "%s" tag.', 'stephanie-king'), $tag) ),
				"type" => "section",
				);
	
			foreach ($v as $css_prop=>$css_value) {
				if (in_array($css_prop, array('title', 'description'))) continue;
				$options = '';
				$type = 'text';
				$title = ucfirst(str_replace('-', ' ', $css_prop));
				if ($css_prop == 'font-family') {
					$type = 'select';
					$options = array();
				} else if ($css_prop == 'font-weight') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'stephanie-king'),
						'100' => esc_html__('100 (Light)', 'stephanie-king'), 
						'200' => esc_html__('200 (Light)', 'stephanie-king'), 
						'300' => esc_html__('300 (Thin)',  'stephanie-king'),
						'400' => esc_html__('400 (Normal)', 'stephanie-king'),
						'500' => esc_html__('500 (Semibold)', 'stephanie-king'),
						'600' => esc_html__('600 (Semibold)', 'stephanie-king'),
						'700' => esc_html__('700 (Bold)', 'stephanie-king'),
						'800' => esc_html__('800 (Black)', 'stephanie-king'),
						'900' => esc_html__('900 (Black)', 'stephanie-king')
					);
				} else if ($css_prop == 'font-style') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'stephanie-king'),
						'normal' => esc_html__('Normal', 'stephanie-king'), 
						'italic' => esc_html__('Italic', 'stephanie-king')
					);
				} else if ($css_prop == 'text-decoration') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'stephanie-king'),
						'none' => esc_html__('None', 'stephanie-king'), 
						'underline' => esc_html__('Underline', 'stephanie-king'),
						'overline' => esc_html__('Overline', 'stephanie-king'),
						'line-through' => esc_html__('Line-through', 'stephanie-king')
					);
				} else if ($css_prop == 'text-transform') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'stephanie-king'),
						'none' => esc_html__('None', 'stephanie-king'), 
						'uppercase' => esc_html__('Uppercase', 'stephanie-king'),
						'lowercase' => esc_html__('Lowercase', 'stephanie-king'),
						'capitalize' => esc_html__('Capitalize', 'stephanie-king')
					);
				}
				$fonts["{$tag}_{$css_prop}"] = array(
					"title" => $title,
					"desc" => '',
					"refresh" => false,
					"std" => '$stephanie_king_get_theme_fonts_option',
					"options" => $options,
					"type" => $type
				);
			}
			
			$fonts["{$tag}_section_end"] = array(
				"type" => "section_end"
				);
		}

		$fonts['fonts_end'] = array(
			"type" => "panel_end"
			);

		// Add fonts parameters into Theme Options
		stephanie_king_storage_merge_array('options', '', $fonts);

		// Add Header Video if WP version < 4.7
		if (!function_exists('get_header_video_url')) {
			stephanie_king_storage_set_array_after('options', 'header_image_override', 'header_video', array(
				"title" => esc_html__('Header video', 'stephanie-king'),
				"desc" => wp_kses_data( __("Select video to use it as background for the header", 'stephanie-king') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'stephanie-king')
				),
				"std" => '',
				"type" => "video"
				)
			);
		}
	}
}


// Return lists with choises when its need in the admin mode
if (!function_exists('stephanie_king_options_get_list_choises')) {
	add_filter('stephanie_king_filter_options_get_list_choises', 'stephanie_king_options_get_list_choises', 10, 2);
	function stephanie_king_options_get_list_choises($list, $id) {
		if (is_array($list) && count($list)==0) {
			if (strpos($id, 'header_style')===0)
				$list = stephanie_king_get_list_header_styles(strpos($id, 'header_style_')===0);
			else if (strpos($id, 'header_position')===0)
				$list = stephanie_king_get_list_header_positions(strpos($id, 'header_position_')===0);
			else if (strpos($id, 'header_widgets')===0)
				$list = stephanie_king_get_list_sidebars(strpos($id, 'header_widgets_')===0, true);
			else if (strpos($id, 'header_scheme')===0 
					|| strpos($id, 'menu_scheme')===0
					|| strpos($id, 'color_scheme')===0
					|| strpos($id, 'sidebar_scheme')===0
					|| strpos($id, 'footer_scheme')===0)
				$list = stephanie_king_get_list_schemes($id!='color_scheme');
			else if (strpos($id, 'sidebar_widgets')===0)
				$list = stephanie_king_get_list_sidebars(strpos($id, 'sidebar_widgets_')===0, true);
			else if (strpos($id, 'sidebar_position')===0)
				$list = stephanie_king_get_list_sidebars_positions(strpos($id, 'sidebar_position_')===0);
			else if (strpos($id, 'widgets_above_page')===0)
				$list = stephanie_king_get_list_sidebars(strpos($id, 'widgets_above_page_')===0, true);
			else if (strpos($id, 'widgets_above_content')===0)
				$list = stephanie_king_get_list_sidebars(strpos($id, 'widgets_above_content_')===0, true);
			else if (strpos($id, 'widgets_below_page')===0)
				$list = stephanie_king_get_list_sidebars(strpos($id, 'widgets_below_page_')===0, true);
			else if (strpos($id, 'widgets_below_content')===0)
				$list = stephanie_king_get_list_sidebars(strpos($id, 'widgets_below_content_')===0, true);
			else if (strpos($id, 'footer_style')===0)
				$list = stephanie_king_get_list_footer_styles(strpos($id, 'footer_style_')===0);
			else if (strpos($id, 'footer_widgets')===0)
				$list = stephanie_king_get_list_sidebars(strpos($id, 'footer_widgets_')===0, true);
			else if (strpos($id, 'blog_style')===0)
				$list = stephanie_king_get_list_blog_styles(strpos($id, 'blog_style_')===0);
			else if (strpos($id, 'post_type')===0)
				$list = stephanie_king_get_list_posts_types();
			else if (strpos($id, 'parent_cat')===0)
				$list = stephanie_king_array_merge(array(0 => esc_html__('- Select category -', 'stephanie-king')), stephanie_king_get_list_categories());
			else if (strpos($id, 'blog_animation')===0)
				$list = stephanie_king_get_list_animations_in();
			else if ($id == 'color_scheme_editor')
				$list = stephanie_king_get_list_schemes();
			else if (strpos($id, '_font-family') > 0)
				$list = stephanie_king_get_list_load_fonts(true);
		}
		return $list;
	}
}




// -----------------------------------------------------------------
// -- Create and manage Theme Options
// -----------------------------------------------------------------

// Theme init priorities:
// 2 - create Theme Options
if (!function_exists('stephanie_king_options_theme_setup2')) {
	add_action( 'after_setup_theme', 'stephanie_king_options_theme_setup2', 2 );
	function stephanie_king_options_theme_setup2() {
		stephanie_king_options_create();
	}
}

// Step 1: Load default settings and previously saved mods
if (!function_exists('stephanie_king_options_theme_setup5')) {
	add_action( 'after_setup_theme', 'stephanie_king_options_theme_setup5', 5 );
	function stephanie_king_options_theme_setup5() {
		stephanie_king_storage_set('options_reloaded', false);
		stephanie_king_load_theme_options();
	}
}

// Step 2: Load current theme customization mods
if (is_customize_preview()) {
	if (!function_exists('stephanie_king_load_custom_options')) {
		add_action( 'wp_loaded', 'stephanie_king_load_custom_options' );
		function stephanie_king_load_custom_options() {
			if (!stephanie_king_storage_get('options_reloaded')) {
				stephanie_king_storage_set('options_reloaded', true);
				stephanie_king_load_theme_options();
			}
		}
	}
}

// Load current values for each customizable option
if ( !function_exists('stephanie_king_load_theme_options') ) {
	function stephanie_king_load_theme_options() {
		$options = stephanie_king_storage_get('options');
		$reset = (int) get_theme_mod('reset_options', 0);
		foreach ($options as $k=>$v) {
			if (isset($v['std'])) {
				if (strpos($v['std'], '$stephanie_king_')!==false) {
					$func = substr($v['std'], 1);
					if (function_exists($func)) {
						$v['std'] = $func($k);
					}
				}
				$value = $v['std'];
				if (!$reset) {
					if (isset($_GET[$k]))
						$value = $_GET[$k];
					else {
						$tmp = get_theme_mod($k, -987654321);
						if ($tmp != -987654321) $value = $tmp;
					}
				}
				stephanie_king_storage_set_array2('options', $k, 'val', $value);
				if ($reset) remove_theme_mod($k);
			}
		}
		if ($reset) {
			// Unset reset flag
			set_theme_mod('reset_options', 0);
			// Regenerate CSS with default colors and fonts
			stephanie_king_customizer_save_css();
		} else {
			do_action('stephanie_king_action_load_options');
		}
	}
}

// Override options with stored page/post meta
if ( !function_exists('stephanie_king_override_theme_options') ) {
	add_action( 'wp', 'stephanie_king_override_theme_options', 1 );
	function stephanie_king_override_theme_options($query=null) {
		if (is_page_template('blog.php')) {
			stephanie_king_storage_set('blog_archive', true);
			stephanie_king_storage_set('blog_template', get_the_ID());
		}
		stephanie_king_storage_set('blog_mode', stephanie_king_detect_blog_mode());
		if (is_singular()) {
			stephanie_king_storage_set('options_meta', get_post_meta(get_the_ID(), 'stephanie_king_options', true));
		}
	}
}


// Return customizable option value
if (!function_exists('stephanie_king_get_theme_option')) {
	function stephanie_king_get_theme_option($name, $defa='', $strict_mode=false, $post_id=0) {
		$rez = $defa;
		$from_post_meta = false;
		if ($post_id > 0) {
			if (!stephanie_king_storage_isset('post_options_meta', $post_id))
				stephanie_king_storage_set_array('post_options_meta', $post_id, get_post_meta($post_id, 'stephanie_king_options', true));
			if (stephanie_king_storage_isset('post_options_meta', $post_id, $name)) {
				$tmp = stephanie_king_storage_get_array('post_options_meta', $post_id, $name);
				if (!stephanie_king_is_inherit($tmp)) {
					$rez = $tmp;
					$from_post_meta = true;
				}
			}
		}
		if (!$from_post_meta && stephanie_king_storage_isset('options')) {
			$blog_mode = stephanie_king_storage_get('blog_mode');
			if ( !stephanie_king_storage_isset('options', $name) && (empty($blog_mode) || !stephanie_king_storage_isset('options', $name.'_'.$blog_mode)) ) {
				$rez = $tmp = '_not_exists_';
				if (function_exists('trx_addons_get_option'))
					$rez = trx_addons_get_option($name, $tmp, false);
				if ($rez === $tmp) {
					if ($strict_mode) {
						$s = debug_backtrace();
						$s = array_shift($s);
						echo '<pre>' . sprintf(esc_html__('Undefined option "%s" called from:', 'stephanie-king'), $name);
						if (function_exists('dco')) dco($s);
						else print_r($s);
						echo '</pre>';
						wp_die();
					} else
						$rez = $defa;
				}
			} else {
				// Override option from GET or POST for current blog mode
				if (!empty($blog_mode) && isset($_REQUEST[$name . '_' . $blog_mode])) {
					$rez = $_REQUEST[$name . '_' . $blog_mode];
				// Override option from GET
				} else if (isset($_REQUEST[$name])) {
					$rez = $_REQUEST[$name];
				// Override option from current page settings (if exists)
				} else if (stephanie_king_storage_isset('options_meta', $name) && !stephanie_king_is_inherit(stephanie_king_storage_get_array('options_meta', $name))) {
					$rez = stephanie_king_storage_get_array('options_meta', $name);
				// Override option from current blog mode settings: 'home', 'search', 'page', 'post', 'blog', etc. (if exists)
				} else if (!empty($blog_mode) && stephanie_king_storage_isset('options', $name . '_' . $blog_mode, 'val') && !stephanie_king_is_inherit(stephanie_king_storage_get_array('options', $name . '_' . $blog_mode, 'val'))) {
					$rez = stephanie_king_storage_get_array('options', $name . '_' . $blog_mode, 'val');
				// Get saved option value
				} else if (stephanie_king_storage_isset('options', $name, 'val')) {
					$rez = stephanie_king_storage_get_array('options', $name, 'val');
				// Get ThemeREX Addons option value
				} else if (function_exists('trx_addons_get_option')) {
					$rez = trx_addons_get_option($name, $defa, false);
				}
			}
		}
		return $rez;
	}
}


// Check if customizable option exists
if (!function_exists('stephanie_king_check_theme_option')) {
	function stephanie_king_check_theme_option($name) {
		return stephanie_king_storage_isset('options', $name);
	}
}


// Get dependencies list from the Theme Options
if ( !function_exists('stephanie_king_get_theme_dependencies') ) {
	function stephanie_king_get_theme_dependencies() {
		$options = stephanie_king_storage_get('options');
		$depends = array();
		foreach ($options as $k=>$v) {
			if (isset($v['dependency'])) 
				$depends[$k] = $v['dependency'];
		}
		return $depends;
	}
}

// Return internal theme setting value
if (!function_exists('stephanie_king_get_theme_setting')) {
	function stephanie_king_get_theme_setting($name) {
		if ( !stephanie_king_storage_isset('settings', $name) ) {
			$s = debug_backtrace();
			$s = array_shift($s);
			echo '<pre>' . sprintf(esc_html__('Undefined setting "%s" called from:', 'stephanie-king'), $name);
			if (function_exists('dco')) dco($s);
			else print_r($s);
			echo '</pre>';
			wp_die();
		} else
			return stephanie_king_storage_get_array('settings', $name);
	}
}

// Set theme setting
if ( !function_exists( 'stephanie_king_set_theme_setting' ) ) {
	function stephanie_king_set_theme_setting($option_name, $value) {
		if (stephanie_king_storage_isset('settings', $option_name))
			stephanie_king_storage_set_array('settings', $option_name, $value);
	}
}
?>