<?php
/**
 * Setup theme-specific fonts and colors
 *
 * @package WordPress
 * @subpackage STEPHANIE_KING
 * @since STEPHANIE_KING 1.0.22
 */

// Theme init priorities:
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
if ( !function_exists('stephanie_king_customizer_theme_setup1') ) {
	add_action( 'after_setup_theme', 'stephanie_king_customizer_theme_setup1', 1 );
	function stephanie_king_customizer_theme_setup1() {
		
		// -----------------------------------------------------------------
		// -- Theme fonts (Google and/or custom fonts)
		// -----------------------------------------------------------------
		
		// Fonts to load when theme start
		// It can be Google fonts or uploaded fonts, placed in the folder /css/font-face/font-name inside the theme folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		// For example: font name 'TeX Gyre Termes', folder 'TeX-Gyre-Termes'
		stephanie_king_storage_set('load_fonts', array(
			// Font-face packed with theme
			array(
				'name'   => 'Metropolis',
				'family' => 'sans-serif'
				),
			array(
				'name'   => 'NimbusRomNo9L',
				'family' => 'serif'
				)
		));
		
		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		stephanie_king_storage_set('load_fonts_subset', 'latin,latin-ext');
		
		// Settings of the main tags
		stephanie_king_storage_set('theme_fonts', array(
			'p' => array(
				'title'				=> esc_html__('Main text', 'stephanie-king'),
				'description'		=> esc_html__('Font settings of the main text of the site', 'stephanie-king'),
				'font-family'		=> 'Metropolis, sans-serif',
				'font-size' 		=> '1rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '1.8em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '',
				'margin-top'		=> '0em',
				'margin-bottom'		=> '1.7em'
				),
			'h1' => array(
				'title'				=> esc_html__('Heading 1', 'stephanie-king'),
				'font-family'		=> 'NimbusRomNo9L, serif',
				'font-size' 		=> '5rem',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0',
				'margin-top'		=> '0.76em',
				'margin-bottom'		=> '0.59em'
				),
			'h2' => array(
				'title'				=> esc_html__('Heading 2', 'stephanie-king'),
				'font-family'		=> 'NimbusRomNo9L, serif',
				'font-size' 		=> '3.667rem',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.19',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0',
				'margin-top'		=> '1.14em',
				'margin-bottom'		=> '0.64em'
				),
			'h3' => array(
				'title'				=> esc_html__('Heading 3', 'stephanie-king'),
				'font-family'		=> 'NimbusRomNo9L, serif',
				'font-size' 		=> '2.4rem',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.28',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0',
				'margin-top'		=> '1.3em',
				'margin-bottom'		=> '0.5em'
				),
			'h4' => array(
				'title'				=> esc_html__('Heading 4', 'stephanie-king'),
				'font-family'		=> 'Metropolis, sans-serif',
				'font-size' 		=> '2.133rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '1.2',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0',
				'margin-top'		=> '1.6em',
				'margin-bottom'		=> '0.57em'
				),
			'h5' => array(
				'title'				=> esc_html__('Heading 5', 'stephanie-king'),
				'font-family'		=> 'Metropolis, sans-serif',
				'font-size' 		=> '1.6rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '1.35',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '1.8em',
				'margin-bottom'		=> '0.85em'
				),
			'h6' => array(
				'title'				=> esc_html__('Heading 6', 'stephanie-king'),
				'font-family'		=> 'Metropolis, sans-serif',
				'font-size' 		=> '1.2rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '1.35',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '2.1176em',
				'margin-bottom'		=> '1.5em'
				),
			'logo' => array(
				'title'				=> esc_html__('Logo text', 'stephanie-king'),
				'description'		=> esc_html__('Font settings of the text case of the logo', 'stephanie-king'),
				'font-family'		=> 'NimbusRomNo9L, serif',
				'font-size' 		=> '2em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.25em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '1px'
				),
			'button' => array(
				'title'				=> esc_html__('Buttons', 'stephanie-king'),
				'font-family'		=> 'Metropolis, sans-serif',
				'font-size' 		=> '1rem',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0'
				),
			'input' => array(
				'title'				=> esc_html__('Input fields', 'stephanie-king'),
				'description'		=> esc_html__('Font settings of the input fields, dropdowns and textareas', 'stephanie-king'),
				'font-family'		=> 'Metropolis, sans-serif',
				'font-size' 		=> '14px',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '1.2em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px'
				),
			'info' => array(
				'title'				=> esc_html__('Post meta', 'stephanie-king'),
				'description'		=> esc_html__('Font settings of the post meta: date, counters, share, etc.', 'stephanie-king'),
				'font-family'		=> 'Metropolis, sans-serif',
				'font-size' 		=> '14px',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '0.4em',
				'margin-bottom'		=> ''
				),
			'menu' => array(
				'title'				=> esc_html__('Main menu', 'stephanie-king'),
				'description'		=> esc_html__('Font settings of the main menu items', 'stephanie-king'),
				'font-family'		=> 'NimbusRomNo9L, serif',
				'font-size' 		=> '19px',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px'
				),
			'submenu' => array(
				'title'				=> esc_html__('Dropdown menu', 'stephanie-king'),
				'description'		=> esc_html__('Font settings of the dropdown menu items', 'stephanie-king'),
				'font-family'		=> 'NimbusRomNo9L, serif',
				'font-size' 		=> '19px',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px'
				)
		));
		
		
		// -----------------------------------------------------------------
		// -- Theme colors for customizer
		// -- Attention! Inner scheme must be last in the array below
		// -----------------------------------------------------------------
		stephanie_king_storage_set('scheme_color_groups', array(
			'main'	=> array(
							'title'			=> esc_html__('Main', 'stephanie-king'),
							'description'	=> esc_html__('Colors of the main content area', 'stephanie-king')
							),
			'alter'	=> array(
							'title'			=> esc_html__('Alter', 'stephanie-king'),
							'description'	=> esc_html__('Colors of the alternative blocks (sidebars, etc.)', 'stephanie-king')
							),
			'extra'	=> array(
							'title'			=> esc_html__('Extra', 'stephanie-king'),
							'description'	=> esc_html__('Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'stephanie-king')
							),
			'inverse' => array(
							'title'			=> esc_html__('Inverse', 'stephanie-king'),
							'description'	=> esc_html__('Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'stephanie-king')
							),
			'input'	=> array(
							'title'			=> esc_html__('Input', 'stephanie-king'),
							'description'	=> esc_html__('Colors of the form fields (text field, textarea, select, etc.)', 'stephanie-king')
							),
			)
		);
		stephanie_king_storage_set('scheme_color_names', array(
			'bg_color'	=> array(
							'title'			=> esc_html__('Background color', 'stephanie-king'),
							'description'	=> esc_html__('Background color of this block in the normal state', 'stephanie-king')
							),
			'bg_hover'	=> array(
							'title'			=> esc_html__('Background hover', 'stephanie-king'),
							'description'	=> esc_html__('Background color of this block in the hovered state', 'stephanie-king')
							),
			'bd_color'	=> array(
							'title'			=> esc_html__('Border color', 'stephanie-king'),
							'description'	=> esc_html__('Border color of this block in the normal state', 'stephanie-king')
							),
			'bd_hover'	=>  array(
							'title'			=> esc_html__('Border hover', 'stephanie-king'),
							'description'	=> esc_html__('Border color of this block in the hovered state', 'stephanie-king')
							),
			'text'		=> array(
							'title'			=> esc_html__('Text', 'stephanie-king'),
							'description'	=> esc_html__('Color of the plain text inside this block', 'stephanie-king')
							),
			'text_dark'	=> array(
							'title'			=> esc_html__('Text dark', 'stephanie-king'),
							'description'	=> esc_html__('Color of the dark text (bold, header, etc.) inside this block', 'stephanie-king')
							),
			'text_light'=> array(
							'title'			=> esc_html__('Text light', 'stephanie-king'),
							'description'	=> esc_html__('Color of the light text (post meta, etc.) inside this block', 'stephanie-king')
							),
			'text_link'	=> array(
							'title'			=> esc_html__('Link', 'stephanie-king'),
							'description'	=> esc_html__('Color of the links inside this block', 'stephanie-king')
							),
			'text_hover'=> array(
							'title'			=> esc_html__('Link hover', 'stephanie-king'),
							'description'	=> esc_html__('Color of the hovered state of links inside this block', 'stephanie-king')
							),
			'text_link2'=> array(
							'title'			=> esc_html__('Link 2', 'stephanie-king'),
							'description'	=> esc_html__('Color of the accented texts (areas) inside this block', 'stephanie-king')
							),
			'text_hover2'=> array(
							'title'			=> esc_html__('Link 2 hover', 'stephanie-king'),
							'description'	=> esc_html__('Color of the hovered state of accented texts (areas) inside this block', 'stephanie-king')
							),
			'text_link3'=> array(
							'title'			=> esc_html__('Link 3', 'stephanie-king'),
							'description'	=> esc_html__('Color of the other accented texts (buttons) inside this block', 'stephanie-king')
							),
			'text_hover3'=> array(
							'title'			=> esc_html__('Link 3 hover', 'stephanie-king'),
							'description'	=> esc_html__('Color of the hovered state of other accented texts (buttons) inside this block', 'stephanie-king')
							)
			)
		);
		stephanie_king_storage_set('schemes', array(
		
			// Color scheme: 'default'
			'default' => array(
				'title'	 => esc_html__('Default', 'stephanie-king'),
				'colors' => array(
					
					// Whole block border and background
					'bg_color'			=> '#ffffff',
					'bd_color'			=> '#ebe1de',
		
					// Text and links colors
					'text'				=> '#666666',
					'text_light'		=> '#b7b7b7',
					'text_dark'			=> '#19121e',
					'text_link'			=> '#a1787e',
					'text_hover'		=> '#1a2041',
					'text_link2'		=> '#a1787e',
					'text_hover2'		=> '#1a2041',
					'text_link3'		=> '#d8c4be',
					'text_hover3'		=> '#1a2041',
					'text_link4'		=> '#a1787e',
					'text_hover4'		=> '#1a2041',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'	=> '#d8c4be',
					'alter_bg_hover'	=> '#1a2041',
					'alter_bd_color'	=> '#ece2df',
					'alter_bd_hover'	=> '#d8c4be',
					'alter_text'		=> '#666666',
					'alter_light'		=> '#a1787e',
					'alter_dark'		=> '#19121e',
					'alter_link'		=> '#a1787e',
					'alter_hover'		=> '#19121e',
					'alter_link2'		=> '#19121e',
					'alter_hover2'		=> '#d8c4be', 
					'alter_link3'		=> '#d8c4be',
					'alter_hover3'		=> '#1a2041',
					'alter_link4'		=> '#d8c4be',
					'alter_hover4'		=> '#ffffff',
		
					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'	=> '#d8c4be',
					'extra_bg_hover'	=> '#d8c4be',
					'extra_bd_color'	=> '#1a2041',
					'extra_bd_hover'	=> '#3d3d3d',
					'extra_text'		=> '#ffffff',
					'extra_light'		=> '#666666',
					'extra_dark'		=> '#19121e',
					'extra_link'		=> '#ffffff',
					'extra_hover'		=> '#1a2041',
					'extra_link2'		=> '#1a2041',
					'extra_hover2'		=> '#a1787e',
					'extra_link3'		=> '#a1787e',
					'extra_hover3'		=> '#ffffff',
		
					// Input fields (form's fields and textarea)
					'input_bg_color'	=> '#ffffff',
					'input_bg_hover'	=> '#ffffff',
					'input_bd_color'	=> '#ece2df',
					'input_bd_hover'	=> '#d8c4be',
					'input_text'		=> '#d8c4be',
					'input_light'		=> '#d8c4be',
					'input_dark'		=> '#a1787e',
					
					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color'	=> '#67bcc1',
					'inverse_bd_hover'	=> '#5aa4a9',
					'inverse_text'		=> '#1d1d1d',
					'inverse_light'		=> '#333333',
					'inverse_dark'		=> '#000000',
					'inverse_link'		=> '#ffffff',
					'inverse_hover'		=> '#1d1d1d'
				)
			),
		
			// Color scheme: 'dark'
			'dark' => array(
				'title'  => esc_html__('Dark', 'stephanie-king'),
				'colors' => array(
					
					// Whole block border and background
					'bg_color'			=> '#060514',
					'bd_color'			=> '#1a2041',
		
					// Text and links colors
					'text'				=> '#fefefe',
					'text_light'		=> '#5f5f5f',
					'text_dark'			=> '#ffffff',
					'text_link'			=> '#d8c4be',
					'text_hover'		=> '#a1787e',
					'text_link2'		=> '#80d572',
					'text_hover2'		=> '#8be77c',
					'text_link3'		=> '#a1787e',
					'text_hover3'		=> '#1a2041',
					'text_link4'		=> '#ffffff',
					'text_hover4'		=> '#a1787e',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'	=> '#1a2041',
					'alter_bg_hover'	=> '#1a2041',
					'alter_bd_color'	=> '#131a3f',
					'alter_bd_hover'	=> '#543f4a',
					'alter_text'		=> '#ffffff',
					'alter_light'		=> '#ffffff',
					'alter_dark'		=> '#ffffff',
					'alter_link'		=> '#d8c4be',
					'alter_hover'		=> '#a1787e',
					'alter_link2'		=> '#d8c4be',
					'alter_hover2'		=> '#ffffff', 
					'alter_link3'		=> '#d8c4be',
					'alter_hover3'		=> '#a1787e',
					'alter_link4'		=> '#ffffff',
					'alter_hover4'		=> '#d8c4be',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'	=> '#a1787e',
					'extra_bg_hover'	=> '#1a2041',
					'extra_bd_color'	=> '#d8c4be',
					'extra_bd_hover'	=> '#3d3d3d',
					'extra_text'		=> '#ffffff',
					'extra_light'		=> '#5f5f5f',
					'extra_dark'		=> '#ffffff',
					'extra_link'		=> '#ffffff',
					'extra_hover'		=> '#1a2041',
					'extra_link2'		=> '#ffffff',
					'extra_hover2'		=> '#1a2041',
					'extra_link3'		=> '#a1787e',
					'extra_hover3'		=> '#ffffff',

					// Input fields (form's fields and textarea)
					'input_bg_color'	=> '#060514',
					'input_bg_hover'	=> '#060514',
					'input_bd_color'	=> '#ffffff',
					'input_bd_hover'	=> '#a1787e',
					'input_text'		=> '#ffffff',
					'input_light'		=> '#d8c4be',
					'input_dark'		=> '#a1787e',
					
					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color'	=> '#e36650',
					'inverse_bd_hover'	=> '#cb5b47',
					'inverse_text'		=> '#1d1d1d',
					'inverse_light'		=> '#5f5f5f',
					'inverse_dark'		=> '#000000',
					'inverse_link'		=> '#ffffff',
					'inverse_hover'		=> '#1d1d1d'
				)
			)
		
		));
	}
}

			
// Additional (calculated) theme-specific colors
// Attention! Don't forget setup custom colors also in the theme.customizer.color-scheme.js
if (!function_exists('stephanie_king_customizer_add_theme_colors')) {
	function stephanie_king_customizer_add_theme_colors($colors) {
		if (substr($colors['text'], 0, 1) == '#') {
			$colors['bg_color_0']  = stephanie_king_hex2rgba( $colors['bg_color'], 0 );
			$colors['bg_color_02']  = stephanie_king_hex2rgba( $colors['bg_color'], 0.2 );
			$colors['bg_color_03']  = stephanie_king_hex2rgba( $colors['bg_color'], 0.3 );
			$colors['bg_color_07']  = stephanie_king_hex2rgba( $colors['bg_color'], 0.7 );
			$colors['bg_color_08']  = stephanie_king_hex2rgba( $colors['bg_color'], 0.8 );
			$colors['bg_color_09']  = stephanie_king_hex2rgba( $colors['bg_color'], 0.9 );
			$colors['alter_bg_color_005']  = stephanie_king_hex2rgba( $colors['alter_bg_color'], 0.05 );
			$colors['alter_bg_color_02']  = stephanie_king_hex2rgba( $colors['alter_bg_color'], 0.2 );
			$colors['alter_bg_color_029']  = stephanie_king_hex2rgba( $colors['alter_bg_color'], 0.29 );
			$colors['alter_bg_color_04']  = stephanie_king_hex2rgba( $colors['alter_bg_color'], 0.4 );
			$colors['alter_bg_color_07']  = stephanie_king_hex2rgba( $colors['alter_bg_color'], 0.7 );
			$colors['alter_bg_color_095']  = stephanie_king_hex2rgba( $colors['alter_bg_color'], 0.95 );
			$colors['alter_bg_hover_05']  = stephanie_king_hex2rgba( $colors['alter_bg_hover'], 0.5 );
			$colors['alter_bg_hover_095']  = stephanie_king_hex2rgba( $colors['alter_bg_hover'], 0.95 );
			$colors['alter_bd_color_02']  = stephanie_king_hex2rgba( $colors['alter_bd_color'], 0.2 );
			$colors['extra_bg_color_07']  = stephanie_king_hex2rgba( $colors['extra_bg_color'], 0.7 );
			$colors['alter_hover2_04']  = stephanie_king_hex2rgba( $colors['alter_hover2'], 0.4 );
			$colors['alter_link3_095']  = stephanie_king_hex2rgba( $colors['alter_link3'], 0.95 );
			$colors['alter_hover3_05']  = stephanie_king_hex2rgba( $colors['alter_hover3'], 0.5 );
			$colors['alter_link4_05']  = stephanie_king_hex2rgba( $colors['alter_link4'], 0.5 );
			$colors['text_dark_02']  = stephanie_king_hex2rgba( $colors['text_dark'], 0.2 );
			$colors['text_dark_03']  = stephanie_king_hex2rgba( $colors['text_dark'], 0.3 );
			$colors['text_dark_04']  = stephanie_king_hex2rgba( $colors['text_dark'], 0.4 );
			$colors['text_dark_07']  = stephanie_king_hex2rgba( $colors['text_dark'], 0.7 );
			$colors['text_link_02']  = stephanie_king_hex2rgba( $colors['text_link'], 0.2 );
			$colors['text_link_05']  = stephanie_king_hex2rgba( $colors['text_link'], 0.5 );
			$colors['text_link_07']  = stephanie_king_hex2rgba( $colors['text_link'], 0.7 );
			$colors['text_link_088']  = stephanie_king_hex2rgba( $colors['text_link'], 0.88 );
			$colors['text_link4_05']  = stephanie_king_hex2rgba( $colors['text_link4'], 0.5 );
			$colors['inverse_link_02']  = stephanie_king_hex2rgba( $colors['inverse_link'], 0.2 );
			$colors['inverse_link_05']  = stephanie_king_hex2rgba( $colors['inverse_link'], 0.5 );
			$colors['inverse_link_07']  = stephanie_king_hex2rgba( $colors['inverse_link'], 0.7 );
			$colors['extra_text_07']  = stephanie_king_hex2rgba( $colors['extra_text'], 0.7 );
			$colors['text_link_blend'] = stephanie_king_hsb2hex(stephanie_king_hex2hsb( $colors['text_link'], 2, -5, 5 ));
			$colors['alter_bg_color_blend'] = stephanie_king_hsb2hex(stephanie_king_hex2hsb( $colors['alter_bg_color'], 0, -1.5, 1.2 ));
			$colors['alter_link_blend'] = stephanie_king_hsb2hex(stephanie_king_hex2hsb( $colors['alter_link'], 2, -5, 5 ));
		} else {
			$colors['bg_color_0'] = '{{ data.bg_color_0 }}';
			$colors['bg_color_02'] = '{{ data.bg_color_02 }}';
			$colors['bg_color_03'] = '{{ data.bg_color_03 }}';
			$colors['bg_color_07'] = '{{ data.bg_color_07 }}';
			$colors['bg_color_08'] = '{{ data.bg_color_08 }}';
			$colors['bg_color_09'] = '{{ data.bg_color_09 }}';
			$colors['alter_bg_color_005'] = '{{ data.alter_bg_color_005 }}';
			$colors['alter_bg_color_02'] = '{{ data.alter_bg_color_02 }}';
			$colors['alter_bg_color_029'] = '{{ data.alter_bg_color_029 }}';
			$colors['alter_bg_color_04'] = '{{ data.alter_bg_color_04 }}';
			$colors['alter_bg_color_07'] = '{{ data.alter_bg_color_07 }}';
			$colors['alter_bg_hover_05'] = '{{ data.alter_bg_hover_05 }}';
			$colors['alter_bg_hover_095'] = '{{ data.alter_bg_hover_095 }}';
			$colors['alter_bd_color_02'] = '{{ data.alter_bd_color_02 }}';
			$colors['extra_bg_color_07'] = '{{ data.extra_bg_color_07 }}';
			$colors['alter_hover2_04'] = '{{ data.alter_hover2_04 }}';
			$colors['alter_link3_095'] = '{{ data.alter_link3_095 }}';
			$colors['alter_hover3_05'] = '{{ data.alter_hover3_05 }}';
			$colors['alter_link4_05'] = '{{ data.alter_link4_05 }}';
			$colors['text_dark_02'] = '{{ data.text_dark_02 }}';
			$colors['text_dark_03'] = '{{ data.text_dark_03 }}';
			$colors['text_dark_04'] = '{{ data.text_dark_04 }}';
			$colors['text_dark_07'] = '{{ data.text_dark_07 }}';
			$colors['text_link_02'] = '{{ data.text_link_02 }}';
			$colors['text_link_05'] = '{{ data.text_link_05 }}';
			$colors['text_link_07'] = '{{ data.text_link_07 }}';
			$colors['text_link_088'] = '{{ data.text_link_088 }}';
			$colors['text_link4_05'] = '{{ data.text_link4_05 }}';
			$colors['inverse_link_02'] = '{{ data.inverse_link_02 }}';
			$colors['inverse_link_05'] = '{{ data.inverse_link_05 }}';
			$colors['inverse_link_07'] = '{{ data.inverse_link_07 }}';
			$colors['extra_text_07'] = '{{ data.extra_text_07 }}';
			$colors['text_link_blend'] = '{{ data.text_link_blend }}';
			$colors['alter_link_blend'] = '{{ data.alter_link_blend }}';
		}
		return $colors;
	}
}


			
// Additional theme-specific fonts rules
// Attention! Don't forget setup fonts rules also in the theme.customizer.color-scheme.js
if (!function_exists('stephanie_king_customizer_add_theme_fonts')) {
	function stephanie_king_customizer_add_theme_fonts($fonts) {
		$rez = array();	
		foreach ($fonts as $tag => $font) {
			if (substr($font['font-family'], 0, 2) != '{{') {
				$rez[$tag.'_font-family'] 		= !empty($font['font-family']) && !stephanie_king_is_inherit($font['font-family'])
														? 'font-family:' . trim($font['font-family']) . ';' 
														: '';
				$rez[$tag.'_font-size'] 		= !empty($font['font-size']) && !stephanie_king_is_inherit($font['font-size'])
														? 'font-size:' . stephanie_king_prepare_css_value($font['font-size']) . ";"
														: '';
				$rez[$tag.'_line-height'] 		= !empty($font['line-height']) && !stephanie_king_is_inherit($font['line-height'])
														? 'line-height:' . trim($font['line-height']) . ";"
														: '';
				$rez[$tag.'_font-weight'] 		= !empty($font['font-weight']) && !stephanie_king_is_inherit($font['font-weight'])
														? 'font-weight:' . trim($font['font-weight']) . ";"
														: '';
				$rez[$tag.'_font-style'] 		= !empty($font['font-style']) && !stephanie_king_is_inherit($font['font-style'])
														? 'font-style:' . trim($font['font-style']) . ";"
														: '';
				$rez[$tag.'_text-decoration'] 	= !empty($font['text-decoration']) && !stephanie_king_is_inherit($font['text-decoration'])
														? 'text-decoration:' . trim($font['text-decoration']) . ";"
														: '';
				$rez[$tag.'_text-transform'] 	= !empty($font['text-transform']) && !stephanie_king_is_inherit($font['text-transform'])
														? 'text-transform:' . trim($font['text-transform']) . ";"
														: '';
				$rez[$tag.'_letter-spacing'] 	= !empty($font['letter-spacing']) && !stephanie_king_is_inherit($font['letter-spacing'])
														? 'letter-spacing:' . trim($font['letter-spacing']) . ";"
														: '';
				$rez[$tag.'_margin-top'] 		= !empty($font['margin-top']) && !stephanie_king_is_inherit($font['margin-top'])
														? 'margin-top:' . stephanie_king_prepare_css_value($font['margin-top']) . ";"
														: '';
				$rez[$tag.'_margin-bottom'] 	= !empty($font['margin-bottom']) && !stephanie_king_is_inherit($font['margin-bottom'])
														? 'margin-bottom:' . stephanie_king_prepare_css_value($font['margin-bottom']) . ";"
														: '';
			} else {
				$rez[$tag.'_font-family']		= '{{ data["'.$tag.'_font-family"] }}';
				$rez[$tag.'_font-size']			= '{{ data["'.$tag.'_font-size"] }}';
				$rez[$tag.'_line-height']		= '{{ data["'.$tag.'_line-height"] }}';
				$rez[$tag.'_font-weight']		= '{{ data["'.$tag.'_font-weight"] }}';
				$rez[$tag.'_font-style']		= '{{ data["'.$tag.'_font-style"] }}';
				$rez[$tag.'_text-decoration']	= '{{ data["'.$tag.'_text-decoration"] }}';
				$rez[$tag.'_text-transform']	= '{{ data["'.$tag.'_text-transform"] }}';
				$rez[$tag.'_letter-spacing']	= '{{ data["'.$tag.'_letter-spacing"] }}';
				$rez[$tag.'_margin-top']		= '{{ data["'.$tag.'_margin-top"] }}';
				$rez[$tag.'_margin-bottom']		= '{{ data["'.$tag.'_margin-bottom"] }}';
			}
		}
		return $rez;
	}
}


//-------------------------------------------------------
//-- Thumb sizes
//-------------------------------------------------------

if ( !function_exists('stephanie_king_customizer_theme_setup') ) {
	add_action( 'after_setup_theme', 'stephanie_king_customizer_theme_setup' );
	function stephanie_king_customizer_theme_setup() {

		// Enable support for Post Thumbnails
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size(370, 0, false);
		
		// Add thumb sizes
		// ATTENTION! If you change list below - check filter's names in the 'trx_addons_filter_get_thumb_size' hook
		$thumb_sizes = apply_filters('stephanie_king_filter_add_thumb_sizes', array(
			'stephanie_king-thumb-huge'		=> array(1280, 658, true),
			'stephanie_king-thumb-big' 		=> array( 813, 489, true),
			'stephanie_king-thumb-med' 		=> array( 370, 208, true),
			'stephanie_king-thumb-tiny' 		=> array(  90,  90, true),
			'stephanie_king-thumb-masonry-big' => array( 760,   0, false),		// Only downscale, not crop
			'stephanie_king-thumb-masonry'		=> array( 370,   0, false),		// Only downscale, not crop
			)
		);
		$mult = stephanie_king_get_theme_option('retina_ready', 1);
		if ($mult > 1) $GLOBALS['content_width'] = apply_filters( 'stephanie_king_filter_content_width', 1170*$mult);
		foreach ($thumb_sizes as $k=>$v) {
			// Add Original dimensions
			add_image_size( $k, $v[0], $v[1], $v[2]);
			// Add Retina dimensions
			if ($mult > 1) add_image_size( $k.'-@retina', $v[0]*$mult, $v[1]*$mult, $v[2]);
		}

	}
}

if ( !function_exists('stephanie_king_customizer_image_sizes') ) {
	add_filter( 'image_size_names_choose', 'stephanie_king_customizer_image_sizes' );
	function stephanie_king_customizer_image_sizes( $sizes ) {
		$thumb_sizes = apply_filters('stephanie_king_filter_add_thumb_sizes', array(
			'stephanie_king-thumb-huge'		=> esc_html__( 'Fullsize image', 'stephanie-king' ),
			'stephanie_king-thumb-big'			=> esc_html__( 'Large image', 'stephanie-king' ),
			'stephanie_king-thumb-med'			=> esc_html__( 'Medium image', 'stephanie-king' ),
			'stephanie_king-thumb-tiny'		=> esc_html__( 'Small square avatar', 'stephanie-king' ),
			'stephanie_king-thumb-masonry-big'	=> esc_html__( 'Masonry Large (scaled)', 'stephanie-king' ),
			'stephanie_king-thumb-masonry'		=> esc_html__( 'Masonry (scaled)', 'stephanie-king' ),
			)
		);
		$mult = stephanie_king_get_theme_option('retina_ready', 1);
		foreach($thumb_sizes as $k=>$v) {
			$sizes[$k] = $v;
			if ($mult > 1) $sizes[$k.'-@retina'] = $v.' '.esc_html__('@2x', 'stephanie-king' );
		}
		return $sizes;
	}
}

// Remove some thumb-sizes from the ThemeREX Addons list
if ( !function_exists( 'stephanie_king_customizer_trx_addons_add_thumb_sizes' ) ) {
	add_filter( 'trx_addons_filter_add_thumb_sizes', 'stephanie_king_customizer_trx_addons_add_thumb_sizes');
	function stephanie_king_customizer_trx_addons_add_thumb_sizes($list=array()) {
		if (is_array($list)) {
			foreach ($list as $k=>$v) {
				if (in_array($k, array(
								'trx_addons-thumb-huge',
								'trx_addons-thumb-big',
								'trx_addons-thumb-medium',
								'trx_addons-thumb-tiny',
								'trx_addons-thumb-masonry-big',
								'trx_addons-thumb-masonry',
								)
							)
						) unset($list[$k]);
			}
		}
		return $list;
	}
}

// and replace removed styles with theme-specific thumb size
if ( !function_exists( 'stephanie_king_customizer_trx_addons_get_thumb_size' ) ) {
	add_filter( 'trx_addons_filter_get_thumb_size', 'stephanie_king_customizer_trx_addons_get_thumb_size');
	function stephanie_king_customizer_trx_addons_get_thumb_size($thumb_size='') {
		return str_replace(array(
							'trx_addons-thumb-huge',
							'trx_addons-thumb-huge-@retina',
							'trx_addons-thumb-big',
							'trx_addons-thumb-big-@retina',
							'trx_addons-thumb-medium',
							'trx_addons-thumb-medium-@retina',
							'trx_addons-thumb-tiny',
							'trx_addons-thumb-tiny-@retina',
							'trx_addons-thumb-masonry-big',
							'trx_addons-thumb-masonry-big-@retina',
							'trx_addons-thumb-masonry',
							'trx_addons-thumb-masonry-@retina',
							),
							array(
							'stephanie_king-thumb-huge',
							'stephanie_king-thumb-huge-@retina',
							'stephanie_king-thumb-big',
							'stephanie_king-thumb-big-@retina',
							'stephanie_king-thumb-med',
							'stephanie_king-thumb-med-@retina',
							'stephanie_king-thumb-tiny',
							'stephanie_king-thumb-tiny-@retina',
							'stephanie_king-thumb-masonry-big',
							'stephanie_king-thumb-masonry-big-@retina',
							'stephanie_king-thumb-masonry',
							'stephanie_king-thumb-masonry-@retina',
							),
							$thumb_size);
	}
}
?>